.clearfix {
  *zoom: 1;
}
.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
  line-height: 0;
}
.clearfix:after {
  clear: both;
}
.hide-text {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}
.input-block-level {
  display: block;
  width: 100%;
  min-height: 30px;
  -webkit-box-sizing: border-box;
  -moz-box-sizing: border-box;
  box-sizing: border-box;
}
.control.dashboard-dash > .container {
  float: left;
  border-top: 1px solid #ddd;
  width: 50%;
  min-height: 200px;
}
.control.dashboard-dash > .container.container-1 {
  margin: 0 -1px 0 0;
}
.control.dashboard-dash > .container > .placeholder {
  border: 1px dashed #68a;
  height: 40px;
  width: 100%;
  padding: 10px 5px;
  box-sizing: border-box;
}
.control.dashboard-dash > .container.trash {
  display: none;
  background-color: #e4e4e4;
  background-image: -moz-linear-gradient(top, #dddddd, #eeeeee);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#dddddd), to(#eeeeee));
  background-image: -webkit-linear-gradient(top, #dddddd, #eeeeee);
  background-image: -o-linear-gradient(top, #dddddd, #eeeeee);
  background-image: linear-gradient(to bottom, #dddddd, #eeeeee);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffdddddd', endColorstr='#ffeeeeee', GradientType=0);
  border: 1px dashed #a86;
  box-shadow: 0 0 10px rgba(0, 0, 0, 0.5) inset;
  width: 100%;
  border: 1px solid #ddd;
  font-weight: bold;
  padding: 20px 0;
  color: #bbb;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  text-align: center;
  float: none;
  clear: both;
  min-height: 0;
}
.control.dashboard-dash > .container.trash i:before {
  font-size: 60px;
}
.control.dashboard-widget {
  padding: 10px 5px 10px 4px;
  box-sizing: border-box;
  border: 1px solid #ddd;
  border-width: 0 1px 1px 0;
}
.control.dashboard-widget > .handle {
  width: 8px;
  height: 30px;
  background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAYAAAAGCAYAAADgzO9IAAAABmJLR0QA/wD/AP+gvaeTAAAACXBIWXMAAAsTAAALEwEAmpwYAAAAB3RJTUUH2wkeCyEzNuGfhQAAABl0RVh0Q29tbWVudABDcmVhdGVkIHdpdGggR0lNUFeBDhcAAAAVSURBVAjXYzh9+vR/BnyAeAXUMwoAFlwUQUDbs/QAAAAASUVORK5CYII=') repeat;
  float: left;
  margin: 0 15px 0 5px;
  opacity: .75;
}
.control.dashboard-widget > .content {
  float: left;
}
.control.dashboard-widget.ui-sortable-helper {
  background: white;
  box-shadow: 0 0 15px rgba(0, 0, 0, 0.25);
}
.control .label.dashboard-host {
  font-size: 20px;
  margin: 0 0 0 10px;
  font-weight: bold;
  color: rgba(255, 255, 255, 0.75);
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.5);
}
.control.dashboard-header > .icon {
  float: left;
  width: 60px;
  height: 60px;
  margin: 10px;
  -webkit-border-radius: 2px;
  -moz-border-radius: 2px;
  border-radius: 2px;
  border: 1px solid rgba(0, 0, 0, 0.25);
  -webkit-box-shadow: 0 0 2px #ffffff inset;
  -moz-box-shadow: 0 0 2px #ffffff inset;
  box-shadow: 0 0 2px #ffffff inset;
  position: relative;
}
.control.dashboard-header > .icon.ubuntu {
  background-color: #ffa115;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#ffca7b), to(#ffa115));
  background-image: -webkit-radial-gradient(circle, #ffca7b, #ffa115);
  background-image: -moz-radial-gradient(circle, #ffca7b, #ffa115);
  background-image: -o-radial-gradient(circle, #ffca7b, #ffa115);
  background-repeat: no-repeat;
}
.control.dashboard-header > .icon.ubuntu > .image.ubuntu {
  display: block;
}
.control.dashboard-header > .icon.debian {
  background-color: #d70751;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#f94b89), to(#d70751));
  background-image: -webkit-radial-gradient(circle, #f94b89, #d70751);
  background-image: -moz-radial-gradient(circle, #f94b89, #d70751);
  background-image: -o-radial-gradient(circle, #f94b89, #d70751);
  background-repeat: no-repeat;
}
.control.dashboard-header > .icon.debian > .image.debian {
  display: block;
}
.control.dashboard-header > .icon.centos {
  background-color: #932279;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#d447b4), to(#932279));
  background-image: -webkit-radial-gradient(circle, #d447b4, #932279);
  background-image: -moz-radial-gradient(circle, #d447b4, #932279);
  background-image: -o-radial-gradient(circle, #d447b4, #932279);
  background-repeat: no-repeat;
}
.control.dashboard-header > .icon.centos > .image.centos {
  display: block;
}
.control.dashboard-header > .icon.rhel {
  background-color: #ff0000;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#ff6666), to(#ff0000));
  background-image: -webkit-radial-gradient(circle, #ff6666, #ff0000);
  background-image: -moz-radial-gradient(circle, #ff6666, #ff0000);
  background-image: -o-radial-gradient(circle, #ff6666, #ff0000);
  background-repeat: no-repeat;
}
.control.dashboard-header > .icon.rhel > .image.rhel {
  display: block;
}
.control.dashboard-header > .icon.freebsd {
  background-color: #ff0000;
  background-image: -webkit-gradient(radial, center center, 0, center center, 460, from(#ff6666), to(#ff0000));
  background-image: -webkit-radial-gradient(circle, #ff6666, #ff0000);
  background-image: -moz-radial-gradient(circle, #ff6666, #ff0000);
  background-image: -o-radial-gradient(circle, #ff6666, #ff0000);
  background-repeat: no-repeat;
}
.control.dashboard-header > .icon.freebsd > .image.freebsd {
  display: block;
}
.control.dashboard-header > .icon > .bar {
  position: absolute;
  width: 62px;
  padding: 4px 0 5px;
  bottom: -1px;
  left: -1px;
  border-top: 1px solid rgba(0, 0, 0, 0.5);
  -webkit-border-radius: 0 0 2px 2px;
  -moz-border-radius: 0 0 2px 2px;
  border-radius: 0 0 2px 2px;
  background-color: #5f5f5f;
  background-image: -moz-linear-gradient(top, #666666, #555555);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#666666), to(#555555));
  background-image: -webkit-linear-gradient(top, #666666, #555555);
  background-image: -o-linear-gradient(top, #666666, #555555);
  background-image: linear-gradient(to bottom, #666666, #555555);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff666666', endColorstr='#ff555555', GradientType=0);
  -webkit-box-shadow: 0 1px 0px rgba(255, 255, 255, 0.25) inset;
  -moz-box-shadow: 0 1px 0px rgba(255, 255, 255, 0.25) inset;
  box-shadow: 0 1px 0px rgba(255, 255, 255, 0.25) inset;
  color: white;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.5);
  text-transform: uppercase;
  text-align: center;
  font-weight: bold;
  font-size: 10px;
}
.control.dashboard-header > .icon > .image {
  width: 32px;
  height: 32px;
  position: absolute;
  left: 50%;
  top: 30%;
  margin: -16px;
  display: none;
}
.control.dashboard-header > .labels {
  float: left;
  padding: 8px 0 0;
}
.control.dashboard-header > .labels .hostname {
  font-size: 24px;
  color: #888;
  text-shadow: 0 1px 0 #eee;
  font-weight: bold;
}
.control.dashboard-header > .labels .distro {
  font-size: 16px;
  color: #aaa;
}
.control.dashboard-header > .inner {
  float: right;
  padding: 20px;
}
.control.welcome {
  width: 350px;
  color: #444;
}
