body > .container {
    padding-top: 60px;
}

.browse-item {
    width: 160px;
    margin: 10px 20px 10px 0;

    .image {
        display: block;
        float: left;
        width: 160px;
        height: 90px;
    }

    .title {
        display: block;
        width: 160px;
        text-align: center;
    }

    &.file {
        .image {
            img {
                width: 150px;
            }

            img.one { display: block; }
            img.two { display: none; }

            &:hover {
                img.one { display: none; }
                img.two { display: block; }
            }
        }
    }

    &.directory {
        .image {
            font-size: 64px;
            text-align: center;
        }
    }
}

video {
    width: 800px;
}

.video-meta {
    width: 800px;

    .title {
        font-size: 16px;
        font-weight: bold;
    }

    .timestamp {
        font-family: monospace;
        font-size: 16px;
        float: right;
    }
}