@import "reset.i.less";
@import "mixins.i.less";
@import "vars.i.less";
@import "icons.i.less";
@import "lib.i.less";


@font-face {
    font-family: 'Open Sans';
    font-style: normal;
    font-weight: 400;
    src: local('Open Sans'), local('OpenSans'), url(main/OpenSans.woff) format('woff');
}

@font-face {
    font-family: 'Open Sans';
    font-style: normal; 
    font-weight: 700;
    src: local('Open Sans Bold'), local('OpenSans-Bold'), url(main/OpenSans-Bold.woff) format('woff');
}

@font-face {
  font-family: 'PT Sans';
  font-style: normal;
  font-weight: 700;
  src: local('PT Sans Bold'), local('PTSans-Bold'), url(main/PS-Bold.woff) format('woff');
}

@font-face {
    font-family: 'FontAwesome';
    src: url(main/fontawesome.woff) format('woff');
    font-weight: normal;
    font-style: normal;
}

html {
    height: 100%;
    padding: 0;
}

a, a * {
    .transition(all 0.5s);
    cursor: default;
}

body {
    font-family: @fontFamily;
    font-size: @fontSize;
    overflow-x: hidden;
    overflow-y: scroll;
    position: relative;
	height: 100%;

    .ui-dark & {
        background: url('data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAADIAAAAyCAIAAACRXR/mAAAAAXNSR0IArs4c6QAAAAlwSFlzAAALEwAACxMBAJqcGAAAA8dJREFUWMONWdGOwyAM66WI/9v//wkS0j1wyrm2k7VPG6MhJMZx2M/n87nv+7qu67r23vd9773P1xzP50ygkcs9aefMz89pQU2hzYGTzmddOEeqnyp38cW991przommaFr+FHtv3DF9zWetlRPyMxrSEV1sznne3fDguvl10NYxobgn2qWNpW4dUYGpyMHK7LAJTnMWAZpThE6+q6ggL0/kEHD5BHmz1lK7mlnKozqaLqrfOQ1DRfbDJhEnrbXOOA6mxTNI2821yUvyGA3ihL13pF2CqkVV2rKIwShiOC0YLDbSZqTdTLZNCjmtp5WY6WwGt4EGcVGydj4/kjjnpBOra9us6UpVVMimgu+RxAq8fYrtYpkLWy2qMNP8IORqyg7kK1vqinIVPolUPRnIFKFFoIqfrTkER3QI6cryCx5wOumR+7MkqSSu9Ki/auyJ/xDEdv+hO7uKhxjSMtObqpCMbSFxPg/7sy0mmkciSXKxqp4WXrSB0WgpDVUlY6oIVTxeLZcTghBDULOYq4KkIddgkHNVyONqH60hVr3Yg2arkw2wkYFa6u0LGUKNjRLKQU/WH1ugmrP1fxIrBDRy+Q2JI7ozkJX6Zd5SRUBTVd2qWiRCrmhszqkhV4yORsF9JX0SvtURq+Blm5czOPTYWz1o2bzvdqqyePas7GVOYkW7qpsbbrN8q81SJX4w9aERptcUJUo/WqB6722tw/wMRK61VRFMVUatxxYn2ss8TmKV/q/F+2VRtyUrv5JWeyRRew87btn/hucNKBuM5uCj88lR1UPEy9SQ9fVYHdJjjgHbe0dV8GmjVbWnGFeCUdtrC5uMelSVxx5G2waqzEJsafmzaT2VNF8JK39V3mANtslSF1EavTmtj86HIqFddXXWKCNV0bQdhLWGG4g3TmTZtuJC1aLtf/r7JiNsGnLvhQ35qhDUsFUFl5r1YUu6No+qByk22OseCGLfaw+TNnZpatibO7osqXoYXQAJj8JPvYK9es2YDe2u0LmmeapUSt+O40y8qiTj0dNgL12U8c8OqTFR9vp61xKUgje3PNUGcg0bkkovWUkSCilLE3q7YqVpw3ONxNCb2FBdQadX64lVE28Eu4IMuwFsVYJI9uvfJA3e+4DZrFk+e2j5CkwVI+sNOUlc27pp12QpLZRttbxX/Y/daHUHTr1nVa3/Oh8lLb2IUlbEOPV/qtG2MeP5/5TmIaq/GAiJ+m8RVR4KYdNKUU20/XO87FG1zdKbcOrr+xtGjLpqssCr/eo6/rx2plEVe9PcNoK70oa/tbj/q27ZF4cAAAAASUVORK5CYII=');
    }

    .ui-light & {
        background: #eee;
    }
    
    padding: 0;
    margin: 0;

    > .page {
	    height: 100%;
	}

    &.loading * {
        cursor: wait;
    }
}


.page.auth {
	.content {
		background: white;
		.border-radius(5px);
		.box-shadow(@mainPaneShadow);
		overflow: hidden;
		margin: 50px auto;
		width: 255px;
		padding: 10px 20px;

		.textbox {
			width: 155px;
		}

		.button {
			display: block;
			float: right;
			margin: 5px;
		}

		.l {
			width: 80px;
            float: left;
		}
	}
}

.content-gradient {
    #gradient > .vertical(#fff, #f0f0f0);
}



.clear {
    display: block;
    clear: both;
}

#header {
    #gradient > .vertical(#333, #222);
    height: @headerHeight;
    .box-shadow(0 0 5px rgba(0,0,0,0.5));
    overflow: hidden;
    
    .container {
        width: 960px;
        margin: auto;

        &>.logo {
            .text {
                float: left;
                padding: 1px 20px 0 15px;

                a, div {
                    font-family: 'PT Sans', sans-serif;
                    font-size: 20px;
                    font-weight: bold;
                    color: @orange;
                    text-shadow: 0 -2px 0 rgba(0,0,0,.5);//, 0 1px 0 rgba(255,255,255,.25);
                    text-decoration: none;
                }

                a:hover {
                    text-shadow: 0 0 10px @orange;
                    cursor: pointer;
                }

                .release {
                    color: #c30;
                    display: inline-block;
                }
            }
        }

        .logout, #tab-headers a {
            display: inline-block;
            float: left;
            padding: 8px 10px;
            border-right: 1px solid rgba(0,0,0,.25);
            font-weight: bold;

            &:hover {
                background: rgba(255,255,255,0.125);
            }

            &:active {
                background: rgba(0,0,0,0.125);
            }

            color: #666;
            i:before { color: #666; }

            text-decoration: none;

            &.active {
                #gradient > .vertical(lighten(@orange, 15%), @orange);
                color: darken(@orange, 20%);
                i:before { color: darken(@orange, 20%); }
                text-shadow: 0 1px 0px rgba(255,255,255,.60);
            }

            .close {
                display: inline-block;
                padding: 0 0 0 5px;
            }
        }

        .logout {
            float: right;

            i:before {
                color: #eee;
                position: relative;
                top: 1px;
            }
        }
    }
}

#tabs {
    height: 100%;

    &> div {
        height: 100%;

        &> iframe {
            background: black;
            width: 100%;
            height: 100%;
            border: none;
        }
    }
}


#notifications {
    position: fixed;
    top: 50px;
    right: 20px;
    width: 220px;
    z-index: 100;

    .notification {
        &.info {
            border-left: 5px solid #0d0;
        }
        
        &.error {
            border-left: 5px solid #d00;
        }
        
        #gradient > .vertical(#eee, #fff);
        opacity: .9;
        border-radius: 3px;
        box-shadow: 0 1px 1px rgba(0,0,0,.5);

        width: 200px !important;
        max-height: auto !important;
        height: auto !important;
        text-transform: none !important;
        text-align: left !important;
        position: absolute !important;
        padding: 10px !important;    
    }
}


.full-overlay {
    position: fixed;
    .square(100%);
    left: 0;
    top: 0;
    overflow: hidden;
    display: none;
    z-index: 9000;

    background: rgba(0,0,0,.75);


    >.spinner {
        width: 40px;
        height: 40px;
        @interpolator: cubic-bezier(0.3, 0.5, 0.7, 0.5);
        -webkit-animation: spinner 3s @interpolator infinite;
        -moz-animation: spinner 3s @interpolator infinite;
        animation: spinner 3s @interpolator infinite;

        i::before { 
            font-size: 47px; 
            color: white;
            top: -3px;
        }

        margin: -10px 0 0 -10px;
        position: absolute;
        left: 50%;
        top: 50%;
        opacity: .5;

        &.one {
            margin-left: -30px;
            margin-top: -20px;
        }

        &.two {
            margin-left: 8px;
            animation-direction: reverse;
            -moz-animation-direction: reverse;
            -webkit-animation-direction: reverse;
        }

        &.three {
            margin-left: -6px;
            margin-top: 22px;
            width: 30px;
            height: 30px;

            i::before {
                font-size: 33px;
                top: -1px;
            }
        }
    }

    >.content {
        margin: 60px auto;
        width: 800px;
        padding: 20px;

        >.inner {
            padding: 20px;
            overflow: hidden;

            * {
                color: rgba(255,255,255,.95);
            }

            h1  {
                color: @controlText;
                font-size: 18px;
                margin: 0;
            }

            pre, textarea {
                max-height: 300px;
                color: @controlText;
                font-size: 11px;
                overflow: auto;
            }

            textarea {
                width: 550px;
                height: 200px;
            }
        }
    }
}

#ui-theme-toggle {
    background: rgba(128,128,128,.5);
    position: fixed;
    right: 30px;
    bottom: 30px;
    display: block;
    text-align: center;
    width: 30px;
    height: 30px;
    line-height: 22px;
    border-radius: 5px;

    i::after {
        font-size: 48px;
    }

    &:hover {
        background: rgba(128,128,128,.75);
    }
}

#ssl-alert {
    padding: 6px 10px;
    #gradient > .vertical(#f55, #c00);
    border-bottom: 1px solid #a00;
    border-top: 1px solid #f88;

    b, span, i:before {
        color: white;
        opacity: 1;
        text-shadow: 0 -1px 0 rgba(0,0,0,.5);
    }
}

#connection-error {
    .content {
        margin: 200px auto;

        .inner {
            text-align: center;

            .icon {
                font-family: FontAwesome;
                font-size: 100px;
                color: rgba(255,255,255,.5);
                text-shadow: 0 -1px 0 rgba(0,0,0,.5);
            }
        }
    }
}

#userecho-link {
    -webkit-transform: rotate(-90deg);
    -moz-transform: rotate(-90deg);
    -ms-transform: rotate(-90deg);
    -o-transform: rotate(-90deg);
    transform: rotate(-90deg);
    position: fixed;
    left: -70px;
    font-size: 16px;
    color: #777;
    text-decoration: none;
    border-radius: 5px;
    border: 1px solid #777;
    background: #ddd;
    display: inline-block;
    padding: 10px 20px;
    top: 50%;
    cursor: pointer;
    opacity: .5;

    &:hover {
        opacity: 1;
        left: -60px;
        background: #fff;
    }
}


@-webkit-keyframes spinner {
    0% {
        -webkit-transform: rotate(0);
    }

    100% {
        -webkit-transform: rotate(720deg);
    }
}

@-moz-keyframes spinner {
    from {
       -moz-transform: rotate(0);
    }

    to {
       -moz-transform: rotate(720deg);
    }
}

@keyframes spinner {
    from {
        transform: rotate(0);
    }

    to {
        transform: rotate(720deg);
    }
}

@import "controls.index.i.less";
@import "controls.dialogs.i.less";
@import "controls.select2.i.less";

@import "jquery.ui.i.less";
