(function(){var a;a=(function(){function b(){this.profiles={};this.results={};this.timeout=null;this.stack=[]}b.prototype.start=function(e){var c,d;if(this.profiles[e]){return this.stack.push(null)}else{if((d=(c=this.profiles)[e])==null){c[e]=new Date().getTime()}return this.stack.push(e)}};b.prototype.stop=function(f){var c,d,e=this;if(f==null){f=this.stack.pop()}if(f===null){return}if((d=(c=this.results)[f])==null){c[f]=0}this.results[f]+=new Date().getTime()-this.profiles[f];this.profiles[f]=void 0;clearTimeout(this.timeout);return this.timeout=setTimeout(function(){return e.dump()},1000)};b.prototype.dump=function(){var c;for(c in this.results){console.log("Profiled",c,this.results[c]/1000,"s")}return this.results={}};return b})();window.profiler=new a()}).call(this);