body > .container {
  padding-top: 60px;
}
.browse-item {
  width: 160px;
  margin: 10px 20px 10px 0;
}
.browse-item .image {
  display: block;
  float: left;
  width: 160px;
  height: 90px;
}
.browse-item .title {
  display: block;
  width: 160px;
  text-align: center;
}
.browse-item.file .image img {
  width: 150px;
}
.browse-item.file .image img.one {
  display: block;
}
.browse-item.file .image img.two {
  display: none;
}
.browse-item.file .image:hover img.one {
  display: none;
}
.browse-item.file .image:hover img.two {
  display: block;
}
.browse-item.directory .image {
  font-size: 64px;
  text-align: center;
}
video {
  width: 800px;
}
.video-meta {
  width: 800px;
}
.video-meta .title {
  font-size: 16px;
  font-weight: bold;
}
.video-meta .timestamp {
  font-family: monospace;
  font-size: 16px;
  float: right;
}
